## v0.8.0 (2025-02-08)

### ✨ Features

- enhance _set_bounds function to conditionally set parameter limits (#25)
- add set_bound method for ParamsAccessor (#23)
- improve parameter and component visualization (#22)
- add distinguishable colors to components plot
feat: add parameter status label
- add tolerance to parameter value checks in DisplayAccessor
- add parameter display for DisplayAccessor (#21)

[main d615f12] bump: version 0.7.0 → 0.8.0
 2 files changed, 2 insertions(+), 2 deletions(-)

